@@ -32,7 +32,7 @@ ROW_LSP_EXTERNAL_IDS = 'external_ids'
 ROW_LSP_ENABLED = 'enabled'
 ROW_LSP_DHCPV4_OPTIONS = 'dhcpv4_options'
 ROW_LSP_DHCPV6_OPTIONS = 'dhcpv6_options'
-ROW_LSP_TAG_REQUEST = 'tag_request'
+ROW_LSP_TAG = 'tag'
 ROW_LSP_TYPE = 'type'
 ROW_LSP_OPTIONS = 'options'
 ROW_LSP_PORT_SECURITY = 'port_security'
